@@ -22,4 +22,4 @@ class Process:
                 data["service"]),
             headers=self.headers,
             json=dict_data)
-        return json.loads(response.content)
+        return response
